Groups | Search | Server Info | Keyboard shortcuts | Login | Register [http] [https] [nntp] [nntps]
Groups > comp.sys.apple2.programmer > #1391
| From | Egan Ford <datajerk@gmail.com> |
|---|---|
| Newsgroups | comp.sys.apple2.programmer |
| Subject | Re: Some cc65 optimizations... |
| Date | 2014-11-24 11:14 -0700 |
| Organization | XMission http://xmission.com/ |
| Message-ID | <m4vsip$45n$1@news.xmission.com> (permalink) |
| References | <e499d43f-d51b-4afe-a71a-397e416b2c30@googlegroups.com> <m4qm46$24a$1@dont-email.me> |
On 11/22/14, 11:54 AM, D Finnigan wrote: > Here is his text file: Would be more helpful if: 1. There were actual examples of code size reduction. E.g. this '...' saved 53 bytes, etc... 2. Performance benchmarks. E.g. runs with 67 cycles less.
Back to comp.sys.apple2.programmer | Previous | Next — Previous in thread | Find similar | Unroll thread
Re: Some cc65 optimizations... D Finnigan <dog_cow@macgui.com> - 2014-11-22 12:54 -0600 Re: Some cc65 optimizations... Antoine Vignau <antoine.vignau@laposte.net> - 2014-11-22 13:13 -0800 Re: Some cc65 optimizations... Egan Ford <datajerk@gmail.com> - 2014-11-24 11:14 -0700
csiph-web